/*
 * lomoco - Logitech Mouse Control for Linux
 *
 * Copyright (c) 2007 by Andreas Schneider <mail@cynapses.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * vim: ts=2 sw=2 et cindent
 */

#ifndef _LOMOCO_H
#define _LOMOCO_H

/**
 * @struct lomoco_device_s
 *
 * Used to store all needed information of a lomoco device
 */

/**
 * @typedef logitech_device_t
 * Creates a type name for logitech_device_s
 */
typedef struct lomoco_device_s {
  char *name;
  int vid;
  int pid;
} lomoco_device_t;

/**
 * @struct lomoco_base_s
 *
 * Used to store all needed information for lomoco
 */

/**
 * @typedef logitech_base_t
 * Creates a type name for logitech_base_s
 */
typedef struct lomoco_base_s {
  /** List of Logitech Corded Mice */
  struct lomoco_list_s *logitech_mice_corded;
  /** List of Logitech Cordless Mice */
  struct lomoco_list_s *logitech_mice_cordless;
  /** List of Logitech receivers */
  struct lomoco_list_s *logitech_receiver;
  /** Logitech vendor id */
  int logitech_vid;

  int err_mask;
} lomoco_base_t;

typedef int (*lomoco_device_func) (lomoco_device_t *device);

/**
 * @brief Initializes all needed structures and reads the config file.
 *
 * This function has to be called before you can use any other function. It
 * reads the config file, allocates the base structure and add all information.
 *
 * @param debug_level  Set the debug level of lomoco
 *
 * @return  Returns the initialized base structure
 */
lomoco_base_t *lomoco_init(int debug_level);


/**
 * @brief Get all attached supported devices by lomoco.
 *
 * This function will search for all attached and supported devices. It will
 * call a callback function on every found device.
 *
 * @param base  The initialized base structure.
 * @param fn  The callback function called on every device found.
 * 
 * @return 1 on success, 0 if no device has been found and -1 on an error.
 */
int lomoco_get_devices(lomoco_base_t *base, lomoco_device_func fn);


/**
 * @brief Frees the allocated memory of the base structure.
 *
 * Frees all lists and allocated memory. This function should be called before
 * you exit.
 *
 * @param base  The initialized base structure.
 */
void lomoco_finish(lomoco_base_t *base);

#endif /* _LOMOCO_H */

